:tocdepth: 3

###################
SkyPy Documentation
###################

This package contains methods for modelling the Universe, galaxies and the Milky Way. Also included are methods for generating observed data.


.. _getting-started:

***************
Getting Started
***************


.. _user-docs:

******************
User Documentation
******************

Packages
--------

.. toctree::
   :maxdepth: 1

   cluster/index
   galaxy
   gravitational_wave/index
   halo/index
   power_spectrum/index
   supernova/index
   utils/index

Pipeline
--------

.. toctree::
   :maxdepth: 1

   pipeline/index


.. _developer-docs:

***********************
Developer Documentation
***********************


.. _project-details:

***************
Project details
***************


*****
Index
*****

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

****************
Acknowledgements
****************

Logo Credit: `Maria Fonseca de la Bella <https://www.linkedin.com/in/mariadelabella>`_
